//! @file I_P_I_Pcontroller.hh
//! @brief I-P-I-P制御器
//! @date 2017/06/09
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2017 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#include "I_P_I_Pcontroller.hh"

using namespace ARCS;

//! @brief コンストラクタ
I_P_I_Pcontroller::I_P_I_Pcontroller(double Igain1, double Pgain1, double Igain2, double Pgain2, double SmplTime)
	: Ki1(Igain1), Kp1(Pgain1), Ki2(Igain2), Kp2(Pgain2), Ts(SmplTime), Integ1(nullptr), Integ2(nullptr)
{
	Integ1 = new Integrator(Ts, Integrator::BACKWARD_EULER);
	Integ2 = new Integrator(Ts, Integrator::BACKWARD_EULER);
}

//! @brief デストラクタ
I_P_I_Pcontroller::~I_P_I_Pcontroller(){
	delete Integ1; Integ1 = nullptr;
	delete Integ2; Integ2 = nullptr;
}

//! @brief 制御器出力信号の計算
double I_P_I_Pcontroller::GetSignal(double ref, double res){
	return Integ2->GetSignal(  Integ1->GetSignal(ref - res)*Ki1 - Kp1*res  )*Ki2 - Kp2*res;
}

