//! @file Interface.cc
//! @brief インターフェースクラス
//! @date 2019/04/18
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the BSD License.
// For details, see the License.txt file.

#include <new>
#include <unistd.h>
#include "Interface.hh"
#include "ARCSeventlog.hh"
#include "ARCSassert.hh"
#include "ARCSprint.hh"
#include "PCI-46610x.hh"
#include "WEF-6A.hh"

using namespace ARCS;

// インターフェースボードクラスの定義と実体
namespace {
	// ここにD/A，A/D，エンコーダボードクラス等々の定義と実体を記述する
	PCI46610x* RS422CH1;	// RS422シリアル通信ボード
	WEF6A* ForceSensor;		// 6軸力覚センサ
}

//! @brief コンストラクタ
Interface::Interface(){
	PassedLog();
	
	// ここでD/A，A/D，エンコーダボードクラス等々を生成する
	RS422CH1 = new PCI46610x(0xfb9ff000);	// ←ここのアドレスはlspciコマンドで調べる
	RS422CH1->SetConfig(
		PCI46610x::RATE_921_6kbps,
		PCI46610x::WIRE_4,
		PCI46610x::PARITY_DISABLE,
		PCI46610x::STOPBIT_1,
		PCI46610x::WORDLENG_8
	);
	ForceSensor = new WEF6A(RS422CH1);
	
	PassedLog();
}

//! @brief デストラクタ
Interface::~Interface(){
	SetZeroCurrent();	// 念のためのゼロ電流指令
	delete RS422CH1; RS422CH1 = nullptr;
	delete ForceSensor; ForceSensor = nullptr;
	PassedLog();
}

//! @brief サーボON信号を送出する関数
void Interface::ServoON(void){
	// ここにサーボアンプへのサーボON信号の送出シーケンスを記述する
	
}

//! @brief サーボOFF信号を送出する関数
void Interface::ServoOFF(void){
	// ここにサーボアンプへのサーボOFF信号の送出シーケンスを記述する
	
}

//! @brief 電流指令をゼロに設定する関数
void Interface::SetZeroCurrent(void){
	// ここにゼロ電流指令とサーボアンプの関係を列記する
	
}

//! @brief 位置応答を取得する関数
//! @param[out]	Position	位置応答
void Interface::GetPosition(std::array<double, ConstParams::ACTUATOR_MAX>& Position){
	// ここにエンコーダとPosition配列との関係を列記する
	
}

//! @brief トルク応答を取得する関数
//! @param[out]	Torque	トルク応答
void Interface::GetTorque(std::array<double, ConstParams::ACTUATOR_MAX>& Torque){
	// ここにトルクセンサとTorque配列との関係を列記する
	
}

//! @brief 電流応答を取得する関数
//! @param[out]	Current	電流応答
void Interface::GetCurrent(std::array<double, ConstParams::ACTUATOR_MAX>& Current){
	// ここに電流センサとCurrent配列との関係を列記する
	
}

//! @brief 電流指令を設定する関数
//! @param[in]	Current	電流指令
void Interface::SetCurrent(const std::array<double, ConstParams::ACTUATOR_MAX>& Current){
	// ここにCurrent配列とサーボアンプの関係を列記する
	
}

//! @brief 6軸力覚センサ応答を取得する関数
//! @param[out]	Fx-Fy 各軸の並進力 [N]
//! @param[out]	Mx-My 各軸のトルク [Nm]
void Interface::Get6axisForce(double& Fx, double& Fy, double& Fz, double& Mx, double& My, double& Mz){
	// ここに6軸力覚センサとForce配列との関係を列記する
	ForceSensor->SendForceRequest();	// リクエスト送信
	ForceSensor->WaitForceData();		// データ取得待機(ブロッキング動作)
	ForceSensor->Get6axisForce(Fx, Fy, Fz, Mx, My, Mz);	// [N],[Nm] 力覚センサ値の取得
}

//! @brief Z相クリアに関する設定をする関数
void Interface::SetZpulseClear(const bool flag){
	// インクリメンタルエンコーダのZ(I,C)相クリアの設定が必要な場合に記述する
	
}

