//! @file Interface.cc
//! @brief インターフェースクラス
//! @date 2019/07/30
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the BSD License.
// For details, see the License.txt file.

#include <memory>
#include <unistd.h>
#include "Interface.hh"
#include "ARCSeventlog.hh"
#include "ARCSassert.hh"
#include "ARCSprint.hh"
#include "Limiter.hh"

using namespace ARCS;

// インターフェースボードクラスの定義と実体
namespace {
	// ここにD/A，A/D，エンコーダボードクラス等々の定義と実体をスマートポインタで記述する
	
}

//! @brief コンストラクタ
Interface::Interface(){
	PassedLog();
	
	// ここでD/A，A/D，エンコーダ，シリアル通信，力覚センサクラス等々を生成する
	
	PassedLog();
}

//! @brief デストラクタ
Interface::~Interface(){
	SetZeroCurrent();	// 念のためのゼロ電流指令
	PassedLog();
}

//! @brief サーボON信号を送出する関数
void Interface::ServoON(void){
	// ここにサーボアンプへのサーボON信号の送出シーケンスを記述する
	
}

//! @brief サーボOFF信号を送出する関数
void Interface::ServoOFF(void){
	// ここにサーボアンプへのサーボOFF信号の送出シーケンスを記述する
	
}

//! @brief 電流指令をゼロに設定する関数
void Interface::SetZeroCurrent(void){
	// ここにゼロ電流指令とサーボアンプの関係を列記する
	
}

//! @brief 位置応答を取得する関数
//! @param[out]	PositionRes	位置応答 [rad]
void Interface::GetPosition(std::array<double, ConstParams::ACTUATOR_MAX>& PositionRes){
	// ここにエンコーダとPosition配列との関係を列記する
	
}

//! @brief トルク応答と加速度応答を取得する関数
//! @param[out]	Torque	トルク応答 [Nm]
//! @param[out]	Acceleration	加速度応答 [rad/s^2]
void Interface::GetTorqueAndAcceleration(
	std::array<double, ConstParams::ACTUATOR_MAX>& Torque,
	std::array<double, ConstParams::ACTUATOR_MAX>& Acceleration
){
	// ここにトルクセンサとTorque配列との関係，加速度センサとAcceleration配列との関係を列記する
	
}

//! @brief 電流応答を取得する関数
//! @param[out]	Current	電流応答 [A]
void Interface::GetCurrent(std::array<double, ConstParams::ACTUATOR_MAX>& Current){
	// ここに電流センサとCurrent配列との関係を列記する
	
}

//! @brief 電流指令を設定する関数
//! @param[in]	Current	電流指令 [A]
void Interface::SetCurrent(const std::array<double, ConstParams::ACTUATOR_MAX>& Current){
	// ここにCurrent配列とサーボアンプの関係を列記する
	
}

//! @brief 6軸力覚センサ応答を取得する関数
//! @param[out]	Fx-Fy 各軸の並進力 [N]
//! @param[out]	Mx-My 各軸のトルク [Nm]
void Interface::Get6axisForce(double& Fx, double& Fy, double& Fz, double& Mx, double& My, double& Mz){
	// ここに6軸力覚センサと各変数との関係を列記する
	
}

//! @brief Z相クリアに関する設定をする関数
//! @param[in]	flag	Z相クリアをするか否か
void Interface::SetZpulseClear(const bool flag){
	// インクリメンタルエンコーダのZ(I,C)相クリアの設定が必要な場合に記述する
	
}

//! @brief モータ機械角 [rad] へ換算する関数
//! @param[in]	count	エンコーダカウント値
//! @return	機械角 [rad]
double Interface::ConvMotorAngle(long count){
	return ConstParams::ENC_TO_RADIAN*(double)count;
}

//! @brief モータ電気角 [rad] へ換算する関数
//! @param[in]	count	エンコーダカウント値
//! @return	電気角 [rad] (-2π～+2πの値域循環)
double Interface::ConvElectAngle(long count){
	return ConstParams::ENC_TO_RADIAN*(double)(ConstParams::ENC_POLEPARE*( count % (ConstParams::ENC_MAX_COUNT/ConstParams::ENC_POLEPARE) ));
}

